.. SciPlot-PyQt documentation master file, created by
   sphinx-quickstart on Wed Jul 20 23:57:50 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to SciPlot-PyQt's documentation!
========================================

Contents:

.. toctree::
   :maxdepth: 2



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

